pub struct EscposImage { /* private fields */ }
Image adapted to the printer.

The EscposImage structure keeps the original image, and contains a cache for constructed images for specific printer widths

Implementations

Pub fn creates a new EscposImage from a DynamicImage

The scale parameters goes from 0 to 255, controlling which percentage of the width should the image hold. The justification allows for a bit more specific image alignment.

Creates a cached image for the specified width

Useful method to decrease the number of operations done per printing, by skipping the scaling step for a specific printer.