pub struct PrintDataBuilder { /* private fields */ }

Implementations

Creates a new print data builder

Adds a replacement string

Replacement strings are a simple pattern matching replacement, where all matching instances of target get replaces by replacement

let print_data = PrintDataBuilder::new()
    // Instances of "%name%" will get replaced with "Carlos"
    .replacement("%name%", "Carlos")
    .build();

Note that there is no particular syntax for the target string. "%name%" is used in the example so that the word “name” (in case it appears in the text) is safe from this instruction.