pub struct PrinterProfile { /* private fields */ }
Details required to connect and print

In order to use the full functionality of the library, some information should be provided regarding the printer. The bare minimum information needed is the product id and the vendor id.

Implementations

Create custom printing details

Not recommended to use, as it contains a lot of arguments. See the builder function instead.

Creates a PrinterProfileBuilder

Equivalent to a call to PrinterProfileBuilder’s new function.

// Creates a minimum data structure to connect to a printer
let printer_profile = PrinterProfile::builder(0x0001, 0x0001).build();