Enum escpos_rs::PrinterModel
source · [−]pub enum PrinterModel {
ZKTeco,
TMT20,
}Expand description
Printers known to this library
Probably needs updates. If you know one that is not in the list, send them to the author through email to be considered in future updates.
Variants
ZKTeco
ZKTeco mini printer
TMT20
Epson most used printer
Implementations
sourceimpl PrinterModel
impl PrinterModel