Struct escpos_rs::EscposImage
source · [−]pub struct EscposImage { /* private fields */ }Expand description
Image adapted to the printer.
The EscposImage structure keeps the original image, and contains a cache for constructed images for specific printer widths
Implementations
sourceimpl EscposImage
impl EscposImage
sourcepub fn new(
dynamic_image: DynamicImage,
scale: u8,
justification: Justification
) -> Result<EscposImage, Error>
pub fn new(
dynamic_image: DynamicImage,
scale: u8,
justification: Justification
) -> Result<EscposImage, Error>
Pub fn creates a new EscposImage from a DynamicImage
The scale parameters goes from 0 to 255, controlling which percentage of the width should the image hold. The justification allows for a bit more specific image alignment.
sourcepub fn cache_for(&mut self, width: u16)
pub fn cache_for(&mut self, width: u16)
Creates a cached image for the specified width
Useful method to decrease the number of operations done per printing, by skipping the scaling step for a specific printer.
pub fn feed(&self, width: u16) -> Vec<u8>